All of lore.kernel.org
 help / color / mirror / Atom feed
From: Pu Wen <puwen@hygon.cn>
To: xen-devel@lists.xenproject.org
Cc: "Pu Wen" <puwen@hygon.cn>,
	"Roger Pau Monné" <roger.pau@citrix.com>,
	"Wei Liu" <wei.liu2@citrix.com>,
	"Jan Beulich" <jbeulich@suse.com>,
	"Andrew Cooper" <andrew.cooper3@citrix.com>
Subject: [PATCH 11/15] x86/domctl: Add Hygon Dhyana support
Date: Thu, 20 Dec 2018 21:15:20 +0800	[thread overview]
Message-ID: <619ad06163e1d7b38e3e37851f6aa402a5e703a7.1545284932.git.puwen@hygon.cn> (raw)
In-Reply-To: <cover.1545284932.git.puwen@hygon.cn>

Add Hygon Dhyana support to update cpuid info for creating PV guest.

Signed-off-by: Pu Wen <puwen@hygon.cn>
---
 xen/arch/x86/domctl.c | 13 ++++++++++---
 1 file changed, 10 insertions(+), 3 deletions(-)

diff --git a/xen/arch/x86/domctl.c b/xen/arch/x86/domctl.c
index aa8ad19..a64c724 100644
--- a/xen/arch/x86/domctl.c
+++ b/xen/arch/x86/domctl.c
@@ -175,6 +175,7 @@ static int update_domain_cpuid_info(struct domain *d,
                 mask |= ((uint64_t)edx << 32) | ecx;
                 break;
 
+            case X86_VENDOR_HYGON:
             case X86_VENDOR_AMD:
                 mask &= ((uint64_t)ecx << 32) | edx;
 
@@ -220,7 +221,8 @@ static int update_domain_cpuid_info(struct domain *d,
             uint32_t eax = ctl->eax;
             uint32_t ebx = p->feat._7b0;
 
-            if ( boot_cpu_data.x86_vendor == X86_VENDOR_AMD )
+            if ( boot_cpu_data.x86_vendor == X86_VENDOR_AMD ||
+                 boot_cpu_data.x86_vendor == X86_VENDOR_HYGON )
                 mask &= ((uint64_t)eax << 32) | ebx;
 
             d->arch.pv.cpuidmasks->_7ab0 = mask;
@@ -281,8 +283,12 @@ static int update_domain_cpuid_info(struct domain *d,
             if ( cpu_has_cmp_legacy )
                 ecx |= cpufeat_mask(X86_FEATURE_CMP_LEGACY);
 
-            /* If not emulating AMD, clear the duplicated features in e1d. */
-            if ( p->x86_vendor != X86_VENDOR_AMD )
+            /*
+             * If not emulating AMD and Hygon, clear the duplicated features
+             * in e1d.
+             */
+            if ( p->x86_vendor != X86_VENDOR_AMD &&
+                 p->x86_vendor != X86_VENDOR_HYGON )
                 edx &= ~CPUID_COMMON_1D_FEATURES;
 
             switch ( boot_cpu_data.x86_vendor )
@@ -291,6 +297,7 @@ static int update_domain_cpuid_info(struct domain *d,
                 mask &= ((uint64_t)edx << 32) | ecx;
                 break;
 
+            case X86_VENDOR_HYGON:
             case X86_VENDOR_AMD:
                 mask &= ((uint64_t)ecx << 32) | edx;
 
-- 
2.7.4


_______________________________________________
Xen-devel mailing list
Xen-devel@lists.xenproject.org
https://lists.xenproject.org/mailman/listinfo/xen-devel

  parent reply	other threads:[~2018-12-20 13:15 UTC|newest]

Thread overview: 46+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2018-12-20 13:12 [PATCH 00/15] Add support for Hygon Dhyana Family 18h processor Pu Wen
2018-12-20 13:12 ` [PATCH 01/15] x86/cpu: Create Hygon Dhyana architecture support file Pu Wen
2018-12-21 10:19   ` Andrew Cooper
2018-12-26 11:42     ` Pu Wen
2018-12-27 17:03       ` Roger Pau Monné
2018-12-27 21:09       ` Andrew Cooper
2018-12-28 15:46         ` Pu Wen
2018-12-28 16:21           ` Andrew Cooper
2018-12-20 13:12 ` [PATCH 02/15] x86/cpu/mtrr: Add Hygon Dhyana support to get TOP_MEM2 Pu Wen
2018-12-20 13:12 ` [PATCH 03/15] x86/cpu/vpmu: Add Hygon Dhyana support for vPMU Pu Wen
2018-12-20 14:24   ` Boris Ostrovsky
2018-12-21 10:02     ` Pu Wen
2018-12-21 13:33       ` Boris Ostrovsky
2018-12-21 16:17         ` Pu Wen
2019-01-14 16:03   ` Jan Beulich
2019-01-15 12:49     ` Pu Wen
2019-01-15 13:01       ` Jan Beulich
2019-01-15 16:22         ` Pu Wen
2018-12-20 13:12 ` [PATCH 04/15] x86/cpu/mce: Add Hygon Dhyana support to the MCA infrastructure Pu Wen
2019-01-14 16:23   ` Jan Beulich
2019-01-15 12:52     ` Pu Wen
2019-01-15 13:08       ` Jan Beulich
2018-12-20 13:13 ` [PATCH 05/15] x86/spec_ctrl: Add Hygon Dhyana to the respective mitigation machinery Pu Wen
2018-12-20 13:14 ` [PATCH 06/15] x86/apic: Add Hygon Dhyana support Pu Wen
2018-12-20 13:14 ` [PATCH 07/15] x86/acpi: " Pu Wen
2019-01-14 16:28   ` Jan Beulich
2019-01-15 12:52     ` Pu Wen
2019-01-15 13:09       ` Jan Beulich
2018-12-20 13:14 ` [PATCH 08/15] x86/iommu: " Pu Wen
2018-12-20 13:14 ` [PATCH 09/15] x86/pv: Add Hygon Dhyana support to emulate MSRs access Pu Wen
2019-01-25 17:00   ` Jan Beulich
2019-01-30  9:52     ` Pu Wen
2019-01-30 10:08       ` Jan Beulich
2018-12-20 13:15 ` [PATCH 10/15] x86/domain: Add Hygon Dhyana support Pu Wen
2018-12-20 13:15 ` Pu Wen [this message]
2018-12-20 13:15 ` [PATCH 12/15] x86/traps: " Pu Wen
2019-01-29 11:10   ` Jan Beulich
2019-01-30  9:57     ` Pu Wen
2018-12-20 13:15 ` [PATCH 13/15] x86/xstate: " Pu Wen
2018-12-27 22:40   ` Andrew Cooper
2018-12-29  9:39     ` Pu Wen
2019-01-29 11:15   ` Jan Beulich
2019-01-30 10:47     ` Pu Wen
2018-12-20 13:15 ` [PATCH 14/15] x86/cpuid: " Pu Wen
2018-12-20 13:15 ` [PATCH 15/15] tools/libxc: " Pu Wen
2019-01-02 11:33   ` Wei Liu

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=619ad06163e1d7b38e3e37851f6aa402a5e703a7.1545284932.git.puwen@hygon.cn \
    --to=puwen@hygon.cn \
    --cc=andrew.cooper3@citrix.com \
    --cc=jbeulich@suse.com \
    --cc=roger.pau@citrix.com \
    --cc=wei.liu2@citrix.com \
    --cc=xen-devel@lists.xenproject.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.